==> org.eclipse.papyrus.designer.realtime.architecture.source_2.1.0.202201261931.jar: org/eclipse/papyrus/designer/realtime/architecture/command/CreateRTMLModelCommand.java <==
/*****************************************************************************
 * Copyright (c) 2018 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  Shuai Li (CEA LIST) <shuai.li@cea.fr> - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.designer.realtime.architecture.command;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.papyrus.uml.diagram.common.commands.ModelCreationCommandBase;
import org.eclipse.papyrus.uml.tools.utils.PackageUtil;
import org.eclipse.uml2.uml.Package;
import org.eclipse.uml2.uml.PackageImport;
import org.eclipse.uml2.uml.Profile;
import org.eclipse.uml2.uml.UMLFactory;
import org.eclipse.uml2.uml.resource.UMLResource;

public class CreateRTMLModelCommand extends ModelCreationCommandBase {

	/**
	 * @see org.eclipse.papyrus.infra.core.extension.commands.ModelCreationCommandBase#createRootElement()
	 *
	 * @return
	 */

	@Override
	protected EObject createRootElement() {
		return UMLFactory.eINSTANCE.createModel();
	}

	/**
	 * @see org.eclipse.papyrus.infra.core.extension.commands.ModelCreationCommandBase#initializeModel(org.eclipse.emf.ecore.EObject)
	 *
	 * @param owner
	 */

	@Override
	protected void initializeModel(EObject owner) {
		super.initializeModel(owner);
		Package packageOwner = (Package) owner;

		// Retrieve MARTE profile and apply
		Profile marte = (Profile) PackageUtil.loadPackage(URI.createURI("pathmap://Papyrus_PROFILES/MARTE.profile.uml"), owner.eResource().getResourceSet());
		if (marte != null) {
			PackageUtil.applyProfile(packageOwner, marte, true);
		}

		// Retrieve RealTimeSymbols profile and apply
		Profile realTimeSymbols = (Profile) PackageUtil.loadPackage(URI.createURI("pathmap://PapyrusRealTimeSymbols_PROFILES/RealTimeSymbols.profile.uml"), owner.eResource().getResourceSet());
		if (realTimeSymbols != null) {
			PackageUtil.applyProfile(packageOwner, realTimeSymbols, true);
		}

		Package umlPrimitiveTypes = PackageUtil.loadPackage(URI.createURI(UMLResource.UML_PRIMITIVE_TYPES_LIBRARY_URI), owner.eResource().getResourceSet());
		if (umlPrimitiveTypes != null) {
			PackageImport pi = UMLFactory.eINSTANCE.createPackageImport();
			pi.setImportedPackage(umlPrimitiveTypes);
			packageOwner.getPackageImports().add(pi);
		}
		
		
	}
}

==> org.eclipse.papyrus.designer.realtime.architecture.source_3.2.0.202506230753.jar: org/eclipse/papyrus/designer/realtime/architecture/command/CreateRTMLModelCommand.java <==
/*****************************************************************************
 * Copyright (c) 2018 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  Shuai Li (CEA LIST) <shuai.li@cea.fr> - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.designer.realtime.architecture.command;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.papyrus.uml.diagram.common.commands.ModelCreationCommandBase;
import org.eclipse.papyrus.designer.uml.tools.utils.PackageUtil;
import org.eclipse.uml2.uml.Package;
import org.eclipse.uml2.uml.PackageImport;
import org.eclipse.uml2.uml.Profile;
import org.eclipse.uml2.uml.UMLFactory;
import org.eclipse.uml2.uml.resource.UMLResource;

public class CreateRTMLModelCommand extends ModelCreationCommandBase {

	/**
	 * @see org.eclipse.papyrus.infra.core.extension.commands.ModelCreationCommandBase#createRootElement()
	 *
	 * @return
	 */

	@Override
	protected EObject createRootElement() {
		return UMLFactory.eINSTANCE.createModel();
	}

	/**
	 * @see org.eclipse.papyrus.infra.core.extension.commands.ModelCreationCommandBase#initializeModel(org.eclipse.emf.ecore.EObject)
	 *
	 * @param owner
	 */

	@Override
	protected void initializeModel(EObject owner) {
		super.initializeModel(owner);
		Package packageOwner = (Package) owner;

		// Retrieve MARTE profile and apply
		Profile marte = (Profile) PackageUtil.loadPackage(URI.createURI("pathmap://Papyrus_PROFILES/MARTE.profile.uml"), owner.eResource().getResourceSet());
		if (marte != null) {
			PackageUtil.applyProfile(packageOwner, marte, true);
		}

		// Retrieve RealTimeSymbols profile and apply
		Profile realTimeSymbols = (Profile) PackageUtil.loadPackage(URI.createURI("pathmap://PapyrusRealTimeSymbols_PROFILES/RealTimeSymbols.profile.uml"), owner.eResource().getResourceSet());
		if (realTimeSymbols != null) {
			PackageUtil.applyProfile(packageOwner, realTimeSymbols, true);
		}

		Package umlPrimitiveTypes = PackageUtil.loadPackage(URI.createURI(UMLResource.UML_PRIMITIVE_TYPES_LIBRARY_URI), owner.eResource().getResourceSet());
		if (umlPrimitiveTypes != null) {
			PackageImport pi = UMLFactory.eINSTANCE.createPackageImport();
			pi.setImportedPackage(umlPrimitiveTypes);
			packageOwner.getPackageImports().add(pi);
		}
		
		
	}
}
